@@ -14,6 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import ast
 import collections
 
 from oslo_log import log
@@ -349,7 +350,7 @@ class Syncer(object):
         for strategy_id, synced_strategy in self.strategy_mapping.items():
             filters = {"strategy_id": strategy_id}
             stale_action_plans = objects.ActionPlan.list(
-                self.ctx, filters=filters)
+                self.ctx, filters=filters, eager=True)
 
             # Update strategy IDs for all stale action plans (w/o saving)
             for action_plan in stale_action_plans:
@@ -368,7 +369,7 @@ class Syncer(object):
         for audit_id, synced_audit in self.stale_audits_map.items():
             filters = {"audit_id": audit_id}
             stale_action_plans = objects.ActionPlan.list(
-                self.ctx, filters=filters)
+                self.ctx, filters=filters, eager=True)
 
             # Update audit IDs for all stale action plans (w/o saving)
             for action_plan in stale_action_plans:
@@ -447,7 +448,7 @@ class Syncer(object):
                         audit.id].state = objects.audit.State.CANCELLED
 
             stale_action_plans = objects.ActionPlan.list(
-                self.ctx, filters=filters)
+                self.ctx, filters=filters, eager=True)
             for action_plan in stale_action_plans:
                 LOG.warning(
                     _LW("Action Plan '%(action_plan)s' references a "
@@ -536,11 +537,14 @@ class Syncer(object):
     def _soft_delete_stale_strategies(self, strategy_map, matching_strategies):
         strategy_name = strategy_map.name
         strategy_display_name = strategy_map.display_name
+        parameters_spec = strategy_map.parameters_spec
 
         stale_strategies = []
         for matching_strategy in matching_strategies:
             if (matching_strategy.display_name == strategy_display_name and
-                    matching_strategy.goal_id not in self.goal_mapping):
+                    matching_strategy.goal_id not in self.goal_mapping and
+                    matching_strategy.parameters_spec ==
+                    ast.literal_eval(parameters_spec)):
                 LOG.info(_LI("Strategy %s unchanged"), strategy_name)
             else:
                 LOG.info(_LI("Strategy %s modified"), strategy_name)
